==> php54-owncloud-8.0.3.tgz: share/owncloud/apps/files_sharing/l10n/ca.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "La compartició entre servidors no està activada en aquest servidor",
    "Invalid or untrusted SSL certificate" : "El certificat SSL és invàlid o no és fiable",
    "Couldn't add remote share" : "No s'ha pogut afegir una compartició remota",
    "Shared with you" : "Us han compartit",
    "Shared with others" : "Heu compartit",
    "Shared by link" : "Compartit amb enllaç",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Voleu afegir la compartició remota {nom} des de {owner}@{remote}?",
    "Remote share" : "Compartició remota",
    "Remote share password" : "Contrasenya de compartició remota",
    "Cancel" : "Cancel·la",
    "Add remote share" : "Afegeix compartició remota",
    "Invalid ownCloud url" : "La url d'ownCloud no és vàlida",
    "Share" : "Comparteix",
    "Shared by" : "Compartit per",
    "This share is password-protected" : "Aquest compartit està protegit amb contrasenya",
    "The password is wrong. Try again." : "la contrasenya és incorrecta. Intenteu-ho de nou.",
    "Password" : "Contrasenya",
    "Name" : "Nom",
    "Share time" : "Temps de compartició",
    "Sorry, this link doesn’t seem to work anymore." : "Aquest enllaç sembla que no funciona.",
    "Reasons might be:" : "Les raons podrien ser:",
    "the item was removed" : "l'element ha estat eliminat",
    "the link expired" : "l'enllaç ha vençut",
    "sharing is disabled" : "s'ha desactivat la compartició",
    "For more info, please ask the person who sent this link." : "Per més informació contacteu amb qui us ha enviat l'enllaç.",
    "Add to your ownCloud" : "Afegiu a ownCloud",
    "Download" : "Baixa",
    "Download %s" : "Baixa %s",
    "Direct link" : "Enllaç directe"
},
"nplurals=2; plural=(n != 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files_sharing/l10n/ca.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "La compartició entre servidors no està activada en aquest servidor",
    "Invalid or untrusted SSL certificate" : "El certificat SSL és invàlid o no és fiable",
    "Couldn't add remote share" : "No s'ha pogut afegir una compartició remota",
    "Shared with you" : "Us han compartit",
    "Shared with others" : "Heu compartit",
    "Shared by link" : "Compartit amb enllaç",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Voleu afegir la compartició remota {nom} des de {owner}@{remote}?",
    "Remote share" : "Compartició remota",
    "Remote share password" : "Contrasenya de compartició remota",
    "Cancel" : "Cancel·la",
    "Add remote share" : "Afegeix compartició remota",
    "Invalid ownCloud url" : "La url d'ownCloud no és vàlida",
    "Share" : "Comparteix",
    "Shared by" : "Compartit per",
    "A file or folder has been <strong>shared</strong>" : "S'ha <strong>compartit</strong> un fitxer o una carpeta",
    "You shared %1$s with %2$s" : "Has compartit %1$s amb %2$s",
    "You shared %1$s with group %2$s" : "has compartit %1$s amb el grup %2$s",
    "%2$s shared %1$s with you" : "%2$s ha compartit %1$s amb tu",
    "You shared %1$s via link" : "Heu compartit %1$s via enllaç",
    "Shares" : "Compartits",
    "This share is password-protected" : "Aquest compartit està protegit amb contrasenya",
    "The password is wrong. Try again." : "la contrasenya és incorrecta. Intenteu-ho de nou.",
    "Password" : "Contrasenya",
    "No entries found in this folder" : "No hi ha entrades en aquesta carpeta",
    "Name" : "Nom",
    "Share time" : "Temps de compartició",
    "Sorry, this link doesn’t seem to work anymore." : "Aquest enllaç sembla que no funciona.",
    "Reasons might be:" : "Les raons podrien ser:",
    "the item was removed" : "l'element ha estat eliminat",
    "the link expired" : "l'enllaç ha vençut",
    "sharing is disabled" : "s'ha desactivat la compartició",
    "For more info, please ask the person who sent this link." : "Per més informació contacteu amb qui us ha enviat l'enllaç.",
    "Add to your ownCloud" : "Afegiu a ownCloud",
    "Download" : "Baixa",
    "Download %s" : "Baixa %s",
    "Direct link" : "Enllaç directe"
},
"nplurals=2; plural=(n != 1);");
